Product class

Constructors

Product({required String description, String? freeTrialPeriod, required String price, required ProductType productType, required String sku, required String smallIconUrl, String? subscriptionPeriod, required String title})

Properties

description ↔ String
getter/setter pair
freeTrialPeriod ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
price ↔ String
getter/setter pair
productType ↔ ProductType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String
getter/setter pair
smallIconUrl ↔ String
getter/setter pair
subscriptionPeriod ↔ String?
getter/setter pair
title ↔ String
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → Product