ProductDataResponse class

Constructors

ProductDataResponse({required List<String?> unavailableSkus, required RequestStatus requestStatus, required Map<String?, Product?> productData})

Properties

hashCode → int
The hash code for this object.
no setterinherited
productData ↔ Map<String?, Product?>
getter/setter pair
requestStatus ↔ RequestStatus
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unavailableSkus ↔ List<String?>
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → ProductDataResponse