PurchaseUpdatesResponse class

Constructors

PurchaseUpdatesResponse({UserData? userData, required RequestStatus requestStatus, required List<Receipt?> receipts, required bool hasMore})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMore ↔ bool
getter/setter pair
receipts ↔ List<Receipt?>
getter/setter pair
requestStatus ↔ RequestStatus
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userData ↔ UserData?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → PurchaseUpdatesResponse