Receipt class

Constructors

Receipt({required String receiptId, required String sku, String? termSku, required ProductType productType, required int purchaseDate, int? cancelDate, int? deferredDate, String? deferredSku, required bool isCanceled, required bool isDeferred})

Properties

cancelDate ↔ int?
getter/setter pair
deferredDate ↔ int?
getter/setter pair
deferredSku ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCanceled ↔ bool
getter/setter pair
isDeferred ↔ bool
getter/setter pair
productType ↔ ProductType
getter/setter pair
purchaseDate ↔ int
getter/setter pair
receiptId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String
getter/setter pair
termSku ↔ String?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → Receipt